@@ -5,7 +5,7 @@ use warnings;
 package Log::Any;
 
 # ABSTRACT: Bringing loggers and listeners together
-our $VERSION = '1.710';
+our $VERSION = '1.711';
 
 use Log::Any::Manager;
 use Log::Any::Proxy::Null;
@@ -135,7 +135,7 @@ Log::Any - Bringing loggers and listeners together
 
 =head1 VERSION
 
-version 1.710
+version 1.711
 
 =head1 SYNOPSIS
 
@@ -478,12 +478,16 @@ Stephen Thirlwall <sdt@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords bj5004 cm-perl Jonathan Karen Etheridge Konstantin S. Uvarin Lucas Kanashiro Maros Kollar Maxim Vuets mephinet Michael Conrad Nick Tonkin Paul Durden Philipp Gortan Phill Legault Shlomi Fish
+=for stopwords Andrew Grechkin bj5004 cm-perl Doug Bell Jonathan Karen Etheridge Konstantin S. Uvarin Lucas Kanashiro Maros Kollar Maxim Vuets mephinet Michael Conrad Nick Tonkin Paul Durden Philipp Gortan Phill Legault Shlomi Fish Sven Willenbuecher XSven
 
 =over 4
 
 =item *
 
+Andrew Grechkin <andrew.grechkin@gmail.com>
+
+=item *
+
 bj5004 <bartosz.jakubski@hurra.com>
 
 =item *
@@ -492,6 +496,10 @@ cm-perl <cm-perl@users.noreply.github.com>
 
 =item *
 
+Doug Bell <preaction@users.noreply.github.com>
+
+=item *
+
 Jonathan <jjrs.pam+github@gmail.com>
 
 =item *
@@ -542,6 +550,14 @@ Phill Legault <saladdayllc@gmail.com>
 
 Shlomi Fish <shlomif@shlomifish.org>
 
+=item *
+
+Sven Willenbuecher <sven.willenbuecher@kuehne-nagel.com>
+
+=item *
+
+XSven <XSven@users.noreply.github.com>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
